==> ejc-budgetmanage-impl-3.0.0-20220328.024439-27-sources.jar: com/ejianc/business/record/vo/RecordQuotaanalysisdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 限额设计指标分析变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordQuotaanalysisdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long quotaanalysisId; // 主表id
    private java.lang.String sort; // 序号
    private java.lang.String name; // 名称
    private java.lang.String unit; // 单位
    private java.lang.Double tenderProjectNumber; // 投标工程量
    private java.lang.Double buildArea; // 建筑面积(m²)
    private java.math.BigDecimal tenderTarget; // 投标指标
    private java.math.BigDecimal normTarget; // (计划成本)限额设计指标
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    

    /**
     * 主表id
     */
    public java.lang.Long getQuotaanalysisId() {
        return quotaanalysisId;
    }

    /**
     * 主表id
     */
    public void setQuotaanalysisId(java.lang.Long quotaanalysisId) {
        this.quotaanalysisId = quotaanalysisId;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 投标工程量
     */
    public java.lang.Double getTenderProjectNumber() {
        return tenderProjectNumber;
    }

    /**
     * 投标工程量
     */
    public void setTenderProjectNumber(java.lang.Double tenderProjectNumber) {
        this.tenderProjectNumber = tenderProjectNumber;
    }
    /**
     * 建筑面积(m²)
     */
    public java.lang.Double getBuildArea() {
        return buildArea;
    }

    /**
     * 建筑面积(m²)
     */
    public void setBuildArea(java.lang.Double buildArea) {
        this.buildArea = buildArea;
    }
    /**
     * 投标指标
     */
    public java.math.BigDecimal getTenderTarget() {
        return tenderTarget;
    }

    /**
     * 投标指标
     */
    public void setTenderTarget(java.math.BigDecimal tenderTarget) {
        this.tenderTarget = tenderTarget;
    }
    /**
     * (计划成本)限额设计指标
     */
    public java.math.BigDecimal getNormTarget() {
        return normTarget;
    }

    /**
     * (计划成本)限额设计指标
     */
    public void setNormTarget(java.math.BigDecimal normTarget) {
        this.normTarget = normTarget;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20230324.091733-161-sources.jar: com/ejianc/business/record/vo/RecordQuotaanalysisdetailVO.java <==
package com.ejianc.business.record.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 限额设计指标分析变更记录子表
 * 
 * @author generator
 * 
 */
public class RecordQuotaanalysisdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.Long originalId; // 原始单据id（限额设计指标分析子表）
    private java.lang.String sort; // 序号
    private java.lang.String name; // 名称
    private java.lang.String unit; // 单位
    private java.lang.Double tenderProjectNumber; // 投标工程量
    private java.lang.Double buildArea; // 建筑面积(m²)
    private java.math.BigDecimal tenderTarget; // 投标指标
    private java.math.BigDecimal normTarget; // (计划成本)限额设计指标
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }

    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 投标工程量
     */
    public java.lang.Double getTenderProjectNumber() {
        return tenderProjectNumber;
    }

    /**
     * 投标工程量
     */
    public void setTenderProjectNumber(java.lang.Double tenderProjectNumber) {
        this.tenderProjectNumber = tenderProjectNumber;
    }
    /**
     * 建筑面积(m²)
     */
    public java.lang.Double getBuildArea() {
        return buildArea;
    }

    /**
     * 建筑面积(m²)
     */
    public void setBuildArea(java.lang.Double buildArea) {
        this.buildArea = buildArea;
    }
    /**
     * 投标指标
     */
    public java.math.BigDecimal getTenderTarget() {
        return tenderTarget;
    }

    /**
     * 投标指标
     */
    public void setTenderTarget(java.math.BigDecimal tenderTarget) {
        this.tenderTarget = tenderTarget;
    }
    /**
     * (计划成本)限额设计指标
     */
    public java.math.BigDecimal getNormTarget() {
        return normTarget;
    }

    /**
     * (计划成本)限额设计指标
     */
    public void setNormTarget(java.math.BigDecimal normTarget) {
        this.normTarget = normTarget;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    
}
